"use client";

import { useEffect, useState } from "react";
import Link from "next/link";
import { databases } from "../lib/appwrite";

const DB_ID = process.env.NEXT_PUBLIC_APPWRITE_DB_ID;
const MEMBERS_COLLECTION_ID = "members";
const ASSIGNMENTS_COLLECTION_ID = "assignments";

export default function AdminDashboard() {
  const [stats, setStats] = useState({
    totalMembers: 0,
    pendingAssignments: 0,
  });

  useEffect(() => {
    const fetchStats = async () => {
      try {
        const members = await databases.listDocuments(DB_ID, MEMBERS_COLLECTION_ID);
        const assignments = await databases.listDocuments(DB_ID, ASSIGNMENTS_COLLECTION_ID);

        const pending = assignments.documents.filter(
          (a) => !a.submitted || a.submittedLate
        ).length;

        setStats({
          totalMembers: members.total,
          pendingAssignments: pending,
        });
      } catch (error) {
        console.error("Failed to fetch stats", error);
      }
    };

    fetchStats();
  }, []);

  return (
    <div className="p-6">
      <h1 className="text-3xl font-bold mb-6">Welcome, Admin 👋</h1>

      {/* Stats Section */}
      <div className="grid grid-cols-1 sm:grid-cols-2 gap-6 mb-8">
        <div className="bg-white p-4 shadow rounded-lg">
          <p className="text-gray-500">Total Members</p>
          <h2 className="text-2xl font-bold">{stats.totalMembers}</h2>
        </div>

        <div className="bg-white p-4 shadow rounded-lg">
          <p className="text-gray-500">Pending Assignments</p>
          <h2 className="text-2xl font-bold">{stats.pendingAssignments}</h2>
        </div>
      </div>

      {/* Navigation Buttons */}
      <div className="space-y-4">
        <Link
          href="/admin/members"
          className="block bg-blue-600 hover:bg-blue-700 text-white font-semibold px-4 py-2 rounded"
        >
          ➕ Add or View Members
        </Link>

        <Link
          href="/assignments"
          className="block bg-green-600 hover:bg-green-700 text-white font-semibold px-4 py-2 rounded"
        >
          📋 Manage Assignments
        </Link>
      </div>
    </div>
  );
}
