// app/assignments/page.js
"use client";

import { useEffect, useState } from "react";
import { databases } from "../lib/appwrite"; // Appwrite SDK
import { ID } from "appwrite";

export default function AssignmentsPage() {
  const [assignments, setAssignments] = useState([]);
  const [submissionLinks, setSubmissionLinks] = useState({});
  const [userId, setUserId] = useState(""); // You might fetch this from your auth context/session

  useEffect(() => {
    // Fetch assignments from Appwrite
    const fetchAssignments = async () => {
      try {
        const response = await databases.listDocuments(
          "your_database_id",
          "assignments_collection_id"
        );
        setAssignments(response.documents);
      } catch (error) {
        console.error("Error fetching assignments:", error);
      }
    };

    fetchAssignments();
  }, []);

  const handleSubmit = async (assignmentId) => {
    try {
      await databases.createDocument(
        "67e1452b00016444b37f",
        "67f0f285001a1614b4e8",
        ID.unique(),
        {
          assignmentId,
          userId,
          submissionLink: submissionLinks[assignmentId],
        }
      );

      alert("Submitted!");
    } catch (error) {
      console.error("Submission failed:", error);
    }
  };

  const handleInputChange = (assignmentId, value) => {
    setSubmissionLinks({
      ...submissionLinks,
      [assignmentId]: value,
    });
  };

  return (
    <div>
      <h1 className="text-2xl font-bold mb-4">Assignments</h1>

      {assignments.length === 0 ? (
        <p>No assignments available.</p>
      ) : (
        assignments.map((assignment) => (
          <div key={assignment.$id} className="mb-6 border p-4 rounded-lg">
            <h2 className="text-xl font-semibold">{assignment.title}</h2>
            <p className="text-gray-600">{assignment.description}</p>
            <p className="text-sm text-gray-400">
              Deadline: {assignment.deadline}
            </p>

            <input
              type="text"
              className="mt-2 border px-2 py-1 w-full"
              placeholder="Paste your GitHub/Firebase/Netlify link"
              value={submissionLinks[assignment.$id] || ""}
              onChange={(e) =>
                handleInputChange(assignment.$id, e.target.value)
              }
            />

            <button
              onClick={() => handleSubmit(assignment.$id)}
              className="mt-2 bg-blue-600 text-white px-4 py-1 rounded"
            >
              Submit
            </button>
          </div>
        ))
      )}
    </div>
  );
}
