"use client";
import { useEffect, useState } from "react";
import { databases, databaseId, membersCollectionId } from "../lib/appwrite";

const TestMemberList = () => {
  const [members, setMembers] = useState([]);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchMembers = async () => {
      try {
        const res = await databases.listDocuments(databaseId, membersCollectionId);
        setMembers(res.documents);
      } catch (err) {
        console.error("Error fetching members:", err);
      } finally {
        setLoading(false);
      }
    };

    fetchMembers();
  }, []);

  if (loading) return <p>Loading members...</p>;

  return (
    <div className="p-4">
      <h2 className="text-xl font-bold mb-4">Team Members</h2>
      <ul className="space-y-2">
        {members.map((member) => (
          <li key={member.$id} className="border p-3 rounded shadow-sm">
            <p><strong>Name:</strong> {member.name}</p>
            <p><strong>Email:</strong> {member.email}</p>
            <p><strong>Phone:</strong> {member.phone}</p>
            <p><strong>Role:</strong> {member.role}</p>
            <p><strong>Joined:</strong> {new Date(member.joinDate).toDateString()}</p>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default TestMemberList;
