'use client';

import { useEffect, useState } from "react";
import { getCurrentUser } from "../../utils/auth";
import { databases } from "../../lib/appwrite";

export default function UserProfilePage() {
  const [profile, setProfile] = useState(null);
  const [form, setForm] = useState(null);
  const [docId, setDocId] = useState(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    async function fetchProfile() {
      const user = await getCurrentUser();
      const res = await databases.listDocuments(
        process.env.NEXT_PUBLIC_DB_ID,
        process.env.NEXT_PUBLIC_MEMBERS_COLLECTION_ID,
        [`query.equal("userId", ["${user.$id}"])`]
      );

      const data = res.documents[0];
      setDocId(data.$id);
      setProfile(data);
      setForm({ name: data.name, phone: data.phone });
      setLoading(false);
    }

    fetchProfile();
  }, []);

  const handleChange = (e) => setForm({ ...form, [e.target.name]: e.target.value });

  const handleSubmit = async (e) => {
    e.preventDefault();
    await databases.updateDocument(
      process.env.NEXT_PUBLIC_DB_ID,
      process.env.NEXT_PUBLIC_MEMBERS_COLLECTION_ID,
      docId,
      form
    );
    alert("Profile updated!");
  };

  if (loading) return <p>Loading...</p>;

  return (
    <form onSubmit={handleSubmit} className="p-6 bg-white rounded shadow space-y-4">
      <h2 className="text-xl font-bold">Your Profile</h2>
      <input
        type="text"
        name="name"
        value={form.name}
        onChange={handleChange}
        className="input"
      />
      <input
        type="text"
        name="phone"
        value={form.phone}
        onChange={handleChange}
        className="input"
      />
      <button type="submit" className="btn-primary">Update</button>
    </form>
  );
}
